@@ -2,21 +2,18 @@ from .base import MLServer, RawResponse, FileResponse, JsonResponse, TemplateRes
 
 try:
     from .flask_server import FlaskServer
-except Exception as ex:
+except Exception as ex:  # pragma: no cover
     import warnings
-
     warnings.warn("Can't import FlaskServer. {0}".format(ex))
 
 try:
-    from .quart_server import QuartServer
-except Exception as ex:
+    from .starlette_server import StarletteServer
+except Exception as ex:  # pragma: no cover
     import warnings
-
-    warnings.warn("Can't import QuartServer. {0}".format(ex))
+    warnings.warn("Can't import StarletteServer. {0}".format(ex))
 
 try:
     from .grpc_server import GrpcServer
-except Exception as ex:
+except Exception as ex:  # pragma: no cover
     import warnings
-
     warnings.warn("Can't import GrpcServer. {0}".format(ex))
